<?php
/*
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

WordPress DyaPress plugin :
Copyright (C) 2016-2022      François Pons        <fpons@aytechnet.fr>
 */

class DyaPress {
    private static $instance = null;

    private $page_hooks = array();
    private $options;

    static function get_instance() {
	if ( is_null( self::$instance ) ) {
	    self::$instance = new DyaPress();
	}

	return self::$instance;
    }

    private function __construct() {
	load_plugin_textdomain( 'dyapress', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );

	add_action( 'admin_init', array( &$this, 'register_options' ) );
	add_action( 'admin_init', array( &$this, 'warns_message' ) );
	add_action( 'admin_menu', array( &$this, 'add_admin_pages' ) );
	add_action( 'current_screen', array( &$this, 'dyapress_bufferize' ) );
	add_action( 'admin_enqueue_scripts', array( &$this, 'add_dyapress_scripts' ) );

	add_action( 'plugins_loaded', array( &$this, 'dyapress_trigger' ) );
    }

    function activate() {
	$this->options = get_option( 'dyapress_options' );

	if ($this->options == false) {
	    $this->options = array(
		'show_menutop' => true,
		'permalink' => 'dyapress-' . substr(str_shuffle(MD5(microtime())), 0, 8),
	    );

	    add_option( 'dyapress_options', $this->options );
	} else {
	    $this->options = $this->validate_options( $this->options );

	    update_option( 'dyapress_options', $options );
	}
    }

    function deactivate() {
	delete_option( 'dyapress_options' );
    }

    function uuid() {
	$this->check_licence();

	return get_transient( 'dyap_uuid' );
    }

    function check_licence() {
	$uuid = get_transient( 'dyap_uuid' );

	if ( !isset( $uuid ) || $uuid == '' || false === ( $expire_date = get_transient( 'dyap_expire_date' ) ) ) {
	    $data = array ( 'api_url' => dyap_internal_url( '/api' ) );

	    if ( isset( $uuid ) && $uuid != '' )
		$data['uuid'] = $uuid;

	    $start_time = microtime(true);

	    $response = wp_safe_remote_post( 'https://api.dyapress.com/v1/licences', array(
		'timeout' => 2,
		'headers' => array(
		    'Content-Type' => 'application/json; charset=utf8',
		),
		'user-agent' => 'DyaPress/'.DYAPRESS_VERSION.'; '.site_url(),
		'body' => json_encode( $data ),
		'data_format' => 'body',
	    ) );

	    $response_code = wp_remote_retrieve_response_code( $response );
	    if ( $response_code == 200 ) {
		$result = json_decode( wp_remote_retrieve_body( $response ) );

		$expire_date = $result->licence_expire_date;
		if ( !$expire_date ) {
		    $expire_date = 0;
		    $expiration = 4 * HOUR_IN_SECONDS;
		} else {
		    $expiration = $expire_date - time();
		    if ( $expiration < 0 || $expiration > 4 * HOUR_IN_SECONDS )
			$expiration = 4 * HOUR_IN_SECONDS;
		}

		set_transient( 'dyap_expire_date', $expire_date, $expiration );
		set_transient( 'dyap_uuid', $result->uuid );
	    } else {
		// FIXME: no cache in case of service or network error
		$expire_date = 0;
	    }

	    $end_time = microtime(true);
	    error_log("DyaPress /v1/licences API execution time: ".($end_time - $start_time)." seconds, cached for $expiration seconds");
	}

	return $expire_date;

	/*
	require_once DOL_DOCUMENT_ROOT .'/core/lib/admin.lib.php';
	if ($dyap_action == 'set' && $dyap_user->admin)
	{
	    $resarray = activateModule($value);
	    if (! empty($resarray['errors'])) setEventMessages('', $resarray['errors'], 'errors');
	 */
    }

    // DyaPress function to download some Dolibarr specific files
    function download_plugin_files () {
	global $wp_filesystem;
	if ( empty( $wp_filesystem ) ) {
	    require_once( ABSPATH . 'wp-admin/includes/file.php' );
	    WP_Filesystem();
	}

	if ( ! $wp_filesystem->is_dir( DOL_DOCUMENT_ROOT . '/core' ) ) {
	    error_log( 'trying to download [https://dyapress.com/public/dyapress-files-' . DYAPRESS_VERSION . '.zip]' );
	    $zip_response = wp_remote_request ( 'https://dyapress.com/public/dyapress-files-' . DYAPRESS_VERSION . '.zip', array(
		'method' => 'GET',
		'stream' => true,
		'filename' => DOL_DOCUMENT_ROOT . 'dyapress-files.zip',
	    ) );

	    if ( is_wp_error( $zip_response ) ) {
		$error_code = wp_remote_retrieve_response_code( $zip_response );
		$error_message = wp_remote_retrieve_response_message( $zip_response );
		error_log( "download failed with error_code=$error_code and error_message=$error_message" );

		return $zip_response;
	    }

	    if ( sha1_file( DOL_DOCUMENT_ROOT . 'dyapress-files.zip' ) != DYAPRESS_FILES_SHA1SUM ) {
		return new WP_Error( 'sha1_signature_failed', __( 'Signature check failed on file contents', 'dyapress' ) );
	    }
	    if ( file_exists( DOL_DOCUMENT_ROOT . 'dyapress-files.zip' ) ) {
		$unzip_response = unzip_file( DOL_DOCUMENT_ROOT . 'dyapress-files.zip', DOL_DOCUMENT_ROOT );

		// delete the file downloaded in all cases (success or failure)
		$wp_filesystem->delete( DOL_DOCUMENT_ROOT . 'dyapress-files.zip' );

		return $unzip_response;
	    } else {
		return new WP_Error( 'missing_dyapress_files_archive', __( 'Unable to find DyaPress files archive', 'dyapress' ) );
	    }
	}

	return true;
    }

    // dol_versioncompare() is taken from core/lib/admin.lib.php to avoid loading dyapress right now
    private function dol_versioncompare($versionarray1, $versionarray2)
    {
	$ret = 0;
	$level = 0;
	$count1 = count($versionarray1);
	$count2 = count($versionarray2);
	$maxcount = max($count1, $count2);
	while ($level < $maxcount) {
	    $operande1 = isset($versionarray1[$level]) ? $versionarray1[$level] : 0;
	    $operande2 = isset($versionarray2[$level]) ? $versionarray2[$level] : 0;
	    if (preg_match('/alpha|dev/i', $operande1)) {
		$operande1 = -5;
	    }
	    if (preg_match('/alpha|dev/i', $operande2)) {
		$operande2 = -5;
	    }
	    if (preg_match('/beta$/i', $operande1)) {
		$operande1 = -4;
	    }
	    if (preg_match('/beta$/i', $operande2)) {
		$operande2 = -4;
	    }
	    if (preg_match('/beta([0-9])+/i', $operande1)) {
		$operande1 = -3;
	    }
	    if (preg_match('/beta([0-9])+/i', $operande2)) {
		$operande2 = -3;
	    }
	    if (preg_match('/rc$/i', $operande1)) {
		$operande1 = -2;
	    }
	    if (preg_match('/rc$/i', $operande2)) {
		$operande2 = -2;
	    }
	    if (preg_match('/rc([0-9])+/i', $operande1)) {
		$operande1 = -1;
	    }
	    if (preg_match('/rc([0-9])+/i', $operande2)) {
		$operande2 = -1;
	    }
	    $level++;
	    //print 'level '.$level.' '.$operande1.'-'.$operande2.'<br>';
	    if ($operande1 < $operande2) {
		$ret = -$level;
		break;
	    }
	    if ($operande1 > $operande2) {
		$ret = $level;
		break;
	    }
	}
	return $ret;
    }

    function check_install_dyapress() {
	require_once( dirname(__FILE__) . '/dyapress-init.php' );

	global $dyap_conf, $dyap_db;

	if ( !empty($dyap_conf->global->MAIN_NOT_INSTALLED) || !empty($dyap_conf->global->MAIN_NOT_UPGRADED) )
	    return DYAPRESS_VERSION;

	if (isset($dyap_db)) {
	    $result = $dyap_db->query("SHOW TABLES LIKE '".MAIN_DB_PREFIX."const';");
	    if ($result) {
		$num = $dyap_db->num_rows($result);

		if ($num == 0)
		    return DOL_VERSION;
	    }
	} else {
	    global $wpdb;

	    $result = $wpdb->get_results("SHOW TABLES LIKE '".MAIN_DB_PREFIX."const';");

	    if (empty($result) || count($result) == 0)
		return DOL_VERSION;
	}

	return false;
    }

    function check_upgrade_dyapress() {
	require_once( dirname(__FILE__) . '/dyapress-init.php' );

	global $dyap_conf;

	if ((empty($dyap_conf->global->MAIN_VERSION_LAST_UPGRADE) && empty($dyap_conf->global->MAIN_VERSION_LAST_INSTALL)) && isset($dyap_conf->global->MAIN_MONNAIE))
	    $dyap_conf->global->MAIN_VERSION_LAST_INSTALL = '8.0.2'; // FIXME: only 8.0.2 has been released with both MAIN_VERSION_LAST_UPGRADE and MAIN_VERSION_LAST_INSTALL empty

	if ((!empty($dyap_conf->global->MAIN_VERSION_LAST_UPGRADE) && ($dyap_conf->global->MAIN_VERSION_LAST_UPGRADE != DOL_VERSION)) ||
	    (empty($dyap_conf->global->MAIN_VERSION_LAST_UPGRADE) && !empty($dyap_conf->global->MAIN_VERSION_LAST_INSTALL) && ($dyap_conf->global->MAIN_VERSION_LAST_INSTALL != DOL_VERSION)))
	{
	    $versiontocompare=empty($dyap_conf->global->MAIN_VERSION_LAST_UPGRADE)?$dyap_conf->global->MAIN_VERSION_LAST_INSTALL:$dyap_conf->global->MAIN_VERSION_LAST_UPGRADE;
	    $dolibarrversionlastupgrade=preg_split('/[.-]/',$versiontocompare);
	    $dolibarrversionprogram=preg_split('/[.-]/',DOL_VERSION);
	    $rescomp=$this->dol_versioncompare($dolibarrversionprogram,$dolibarrversionlastupgrade);
	    if ($rescomp > 0)   // Programs have a version higher than database. We did not add "&& $rescomp < 3" because we want upgrade process for build upgrades
		return $versiontocompare;
	}

	// check for upgrade on the same release, we still need to download the archive but without upgrade.
	if ( !file_exists( DOL_DOCUMENT_ROOT . '/core/lib/functions.lib.php' ) )
	    return DYAPRESS_VERSION;

	return false;
    }

    function check_permalink() {
	return get_option( 'permalink_structure' ) ? true : false;
    }

    function warns_message() {
	/*
	$screen = get_current_screen();

	if ( !isset($screen) || preg_match( '/dyapress_plugin/', $screen->id ) )
	    return;
	 */

	if ( !isset($_POST['dyapress_action']) ) {
	    if ( $this->check_install_dyapress() ) {
		$link = 'options-general.php?page=dyapress_plugin';
		$dyap_action = __( 'Install DyaPress', 'dyapress' );
		$msg = __( 'The installation has not been done or is not complete.', 'dyapress' );
	    } elseif ( $version = $this->check_upgrade_dyapress() ) {
		$link = 'options-general.php?page=dyapress_plugin';
		if ( $version == DYAPRESS_VERSION ) {
		    $dyap_action = __( 'Upgrade DyaPress', 'dyapress' );
		    $msg = sprintf( esc_attr__( 'You need to finalize DyaPress installation by download additional plugin files for DyaPress version %s.', 'dyapress' ), $version );
		} else {
		    $dyap_action = __( 'Upgrade DyaPress', 'dyapress' );
		    $msg = sprintf( esc_attr__( 'DyaPress database need to be upgraded as database version %s is lower than DyaPress plugin version %s.', 'dyapress' ), $version, DOL_VERSION );
		}
	    } elseif ( ! $this->check_permalink() ) {
		$link = 'options-permalink.php';
		$dyap_action = __( 'Activate custom permalink for DyaPress', 'dyapress' );
		$msg = __( 'DyaPress need permalink to be activated in order to work correctly. Please activate them.', 'dyapress' );
	    } else {
		$link = '';
		$dyap_action = '';
		$msg = '';
	    }

	    if ( $link && $dyap_action && $msg ) {
		echo '<div class="error"><p><strong><a href="'.$link.'">'.$dyap_action.'</a> : '.$msg.'</strong></p></div>';
	    }
	}
    }

    function dyapress_config() {
	if ( isset($_POST['dyapress_action']) ) {
	    if ( $_POST['dyapress_action'] == 'install' ) {
		// DyaPress is being to be installed
		return $this->admin_install_page();
	    } elseif ( $_POST['dyapress_action'] == 'upgrade' ) {
		// DyaPress is being to be upgraded
		return $this->admin_upgrade_page();
	    }
	} else {
	    if ( $this->check_install_dyapress() ) {
		// DyaPress need to be installed
		return $this->admin_install_page();
	    } elseif ( $this->check_upgrade_dyapress() ) {
		// DyaPress need to be upgraded
		return $this->admin_upgrade_page();
	    } elseif ( $this->check_permalink() ) {
		return $this->admin_option_page();
	    }
	}
    }

    function add_admin_pages() {
	if ( isset($_POST['dyapress_action']) ) {
	    if ( $_POST['dyapress_action'] == 'install' ) {
		// DyaPress is being to be installed
		add_options_page( __( 'Install DyaPress', 'dyapress' ), __( 'Install DyaPress', 'dyapress' ), 'manage_options', 'dyapress_plugin', array( &$this, 'admin_install_page' ) );
	    } elseif ( $_POST['dyapress_action'] == 'upgrade' ) {
		// DyaPress is being to be upgraded
		add_options_page( __( 'Upgrade DyaPress', 'dyapress' ), __( 'Upgrade DyaPress', 'dyapress' ), 'manage_options', 'dyapress_plugin', array( &$this, 'admin_upgrade_page' ) );
	    }
	} else {
	    if ( $this->check_install_dyapress() ) {
		// DyaPress need to be installed
		add_options_page( __( 'Install DyaPress', 'dyapress' ), __( 'Install DyaPress', 'dyapress' ), 'manage_options', 'dyapress_plugin', array( &$this, 'admin_install_page' ) );
	    } elseif ( $this->check_upgrade_dyapress() ) {
		// DyaPress need to be upgraded
		add_options_page( __( 'Upgrade DyaPress', 'dyapress' ), __( 'Upgrade DyaPress', 'dyapress' ), 'manage_options', 'dyapress_plugin', array( &$this, 'admin_upgrade_page' ) );
	    } elseif ( $this->check_permalink() ) {
		if ( $this->add_dyapress_menu() )
		    add_options_page( __( 'Configure DyaPress', 'dyapress' ), __( 'DyaPress', 'dyapress' ), 'manage_options', 'dyapress_plugin', array( &$this, 'admin_option_page' ) );
	    }
	}
    }

    function admin_install_page() {
	if ( ! current_user_can( 'manage_options' ) ) {
	    wp_die( __( 'You do not have rights to access this page.', 'dyapress' ));
	}
?>
<div class="wrap">
	<h2><?php _e( ' Install DyaPress', 'dyapress' ); ?></h2>
<?php
	require_once(dirname(__FILE__) . '/dyapress-init.php');

	$result = $this->download_plugin_files();
	if ( !is_wp_error( $result ) ) {
	    // security define in order to disable direct access
	    define('DYAPRESS_INSTALL_VERSION', DYAPRESS_VERSION);

	    require_once(dirname(__FILE__) . '/dyapress-install.php');

	    if ( isset($_POST['dyapress_action']) && $_POST['dyapress_action'] == 'install' ) {
		// dyapress_install() performs all Dolibarr install steps at once
		\DyaPress\dyapress_install();
?>
	<a href="<?php echo $_SERVER['REQUEST_URI']; ?>" class="button button-primary"><?php _e( 'Configure DyaPress', 'dyapress' ); ?></a>
<?php
		/* FIXME: the following code does not work anymore, so use direct link above
	<form method="post" id="dyapress_configure">
		<p class="submit">
			<input type="hidden" name="dyapress_action" value="configure" />
			<input type="submit" name="submit" id="submit" class="button button-primary" value="<?php _e( 'Configure DyaPress', 'dyapress' ); ?>" />
		</p>
	</form> */
	    } else {
		if ( \DyaPress\dyapress_check_environment() ) {
?>
	<div class="notice notice-warning">
		<h4><?php _e( 'The install process will create all the necessary data tables in your existing database.', 'dyapress' ); ?></h4>
		<p><?php printf( esc_attr__( 'The data tables will all have prefix set to "%s".' ), MAIN_DB_PREFIX ); ?></p>
	</div>
	<form method="post" id="dyapress_install">
		<p class="submit">
			<input type="hidden" name="dyapress_action" value="install" />
			<input type="submit" name="submit" id="submit" class="button button-primary" value="<?php _e( 'Install DyaPress', 'dyapress' ); ?>" />
		</p>
	</form>
<?php	    } else { ?>
	<div class="error">
		<h4><?php _e( 'ERROR: Your website environment is not compatible with DyaPress.', 'dyapress' ); ?></h4>
		<p><?php _e( 'Please fix it to continue the install', 'dyapress' ); ?></p>
	</div>
<?php
		}
	    }
	} else {
?>
	<div class="error">
		<h4><?php _e( 'ERROR: Unable to setup the installation directory', 'dyapress' ); print( ' : ' . implode( ', ', $result->get_error_messages() ) ); ?></h4>
	</div>
<?php
	}
?>
</div>
<?php
    }

    function admin_upgrade_page() {
	if ( ! current_user_can( 'manage_options' ) ) {
	    wp_die( __( 'You do not have rights to access this page.', 'dyapress' ));
	}
?>
<div class="wrap">
	<h2><?php _e( ' Upgrade DyaPress', 'dyapress' ); ?></h2>
<?php
	require_once(dirname(__FILE__) . '/dyapress-init.php');

	$result = $this->download_plugin_files();
	if ( !is_wp_error( $result ) ) {
	    // security define in order to disable direct access
	    define('DYAPRESS_INSTALL_VERSION', DYAPRESS_VERSION);

	    require_once(dirname(__FILE__) . '/dyapress-install.php');
	    if ( isset($_POST['dyapress_action']) && $_POST['dyapress_action'] == 'upgrade' ) {
		// dyapress_upgrade() performs all Dolibarr upgrade steps at once
		\DyaPress\dyapress_upgrade();
?>
	<a href="<?php echo $_SERVER['REQUEST_URI']; ?>" class="button button-primary"><?php _e( 'Configure DyaPress', 'dyapress' ); ?></a>
<?php
		/* FIXME: the following code does not work anymore, so use direct link above
	<form method="post" id="dyapress_configure">
		<p class="submit">
			<input type="hidden" name="dyapress_action" value="configure" />
			<input type="submit" name="submit" id="submit" class="button button-primary" value="<?php _e( 'Configure DyaPress', 'dyapress' ); ?>" />
		</p>
	</form> */
	    } else {
		if ( \DyaPress\dyapress_check_environment() ) {
?>
	<div class="notice notice-warning">
		<h4><?php _e( 'WARNING: the upgrade process will modify your existing data and cannot be undone!', 'dyapress' ); ?></h4>
		<p><?php printf( esc_attr__( 'It is strongly recommended to backup your existing data tables (prefix is set to "%s") before proceding further.' ), MAIN_DB_PREFIX ); ?></p>
		<p><?php printf( esc_attr__( 'The upgrade process will update your database version from %1s to %2s.' ), $this->check_upgrade_dyapress(), DOL_VERSION ); ?></p>
	</div>
	<form method="post" id="dyapress_upgrade">
		<p class="submit">
			<input type="hidden" name="dyapress_action" value="upgrade" />
			<input type="submit" name="submit" id="submit" class="button button-primary" value="<?php _e( 'Upgrade DyaPress', 'dyapress' ); ?>" />
		</p>
	</form>
<?php
		} else { ?>
	<div class="error">
		<h4><?php _e( 'ERROR: Your website environment is not compatible with DyaPress.', 'dyapress' ); ?></h4>
		<p><?php _e( 'Please fix it to continue the upgrade', 'dyapress' ); ?></p>
	</div>
<?php
		}
	    }
	} else {
?>
	<div class="error">
		<h4><?php _e( 'ERROR: Unable to setup the installation directory', 'dyapress' ); print( ' : ' . implode( ', ', $result->get_error_messages() ) ); ?></h4>
	</div>
<?php
	}
?>
</div>
<?php
    }

    function register_options() {
	register_setting( 'dyapress_group', 'dyapress_options', array( &$this, 'validate_options' ) );

	add_settings_section( 'dyapress_settings', __( 'DyaPress settings', 'dyapress' ), array( $this, 'settings_admin_cb' ), 'dyapress_plugin' );

	add_settings_field( 'show_menutop', __( 'Show Dolibarr top menu', 'dyapress' ), array( $this, 'show_menutop_cb' ), 'dyapress_plugin', 'dyapress_settings' );
	add_settings_field( 'permalink', __( 'Internal permalink', 'dyapress' ), array( $this, 'permalink_cb' ), 'dyapress_plugin', 'dyapress_settings' );
    }

    function settings_admin_cb() {
	print '<p>';

	printf( esc_html__( 'Your DyaPress UUID is %s.', 'dyapress' ), '<strong style="background: rgba(255,255,255,.5); box-shadow: inset 0 1px 2px rgba(0,0,0,.04); color: black; margin: 1px; padding: 3px 5px; border: 1px solid #ddd;">'.$this->uuid().'</strong>' );

	if ( $this->check_licence() < time() ) {
	    $premium_url = preg_match( '/fr_/', get_locale() ) ? 'https://dyapress.fr/inscription' : 'https://dyapress.com/signup';
	    printf( ' '.esc_html__( 'You can upgrade to Premium at %s', 'dyapress' ), '<strong><a href="'.$premium_url.'" target="_blank">'.$premium_url.'</a></strong>' );
	}

	print '</p>';
    }

    function show_menutop_cb() {
	printf( '<input type="checkbox" id="show_menutop" name="dyapress_options[show_menutop]" value="true" %s />',
	    isset( $this->options['show_menutop'] ) && $this->options['show_menutop'] ? 'checked' : ''
	);
    }

    function permalink_cb() {
	printf( '<input type="text" id="permalink" name="dyapress_options[permalink]" value="%s" />', $this->options['permalink'] );
    }

    function validate_options( $input ) {
	$new_input = array();

	if ( isset( $input['show_menutop'] ) )
	    $new_input['show_menutop'] = $input['show_menutop'] ? true : false;
	if ( isset( $input['permalink'] ) )
	    $new_input['permalink'] = preg_replace( '/[^\w\-]/', '', $input['permalink'] );

	return $new_input;
    }

    function admin_option_page() {
	if ( ! current_user_can( 'manage_options' ) ) {
	    wp_die( __( 'You do not have rights to access this page.', 'dyapress' ));
	}

	$this->options = get_option( 'dyapress_options' );
?>
<div class="wrap">
	<h1><?php _e( 'Configure DyaPress', 'dyapress' ); ?></h1>
	<form method="post" action="options.php"><?php
	settings_fields( 'dyapress_group' );
	do_settings_sections( 'dyapress_plugin' );
	submit_button();
?>
	</form>
</div>
<?php
    }

    function dyapress_permalink() {
	if ( !isset( $this->options) )
	    $this->options = get_option( 'dyapress_options' );

	$dyapress_permalink = $this->options['permalink'];

	if ( !isset( $dyapress_permalink ) || preg_match( '/^\s*$/', $dyapress_permalink ) ) {
	    // Make sure permalink is defined (an upgrade from 8.0.2.0 does not have a permalink defined)
	    $this->options['permalink'] = 'dyapress-' . substr(str_shuffle(MD5(microtime())), 0, 8);
	    update_option( 'dyapress_options', $this->options );

	    $dyapress_permalink = $this->options['permalink'];
	}

	return $dyapress_permalink;
    }

    function dyapress_trigger() {
	if ( isset($_POST['dyapress_action']) )
	    return;

	# template_redirect to allow rendering a page inside DyaPress as a direct call, checking if access is allowed
	$dyapress_path = parse_url( plugins_url( '/', __FILE__ ), PHP_URL_PATH );
	$dyapress_permalink = $this->dyapress_permalink();

	if ( strpos( $_SERVER['REQUEST_URI'], $dyapress_path ) === 0 ) {
	    error_log("dyapress_trigger begin time from path direct access: ".(microtime(true)-$_SERVER['REQUEST_TIME_FLOAT']));

	    require_once( dirname(__FILE__) . '/dyapress-compat.php' );

	    $ruri = substr( $_SERVER['REQUEST_URI'], strlen($dyapress_path) );
	    if ( preg_match( '/(.*?\.php)/', $ruri, $matches) )
		$rpath = $matches[1];
	    else
		$rpath = parse_url( $ruri, PHP_URL_PATH );
	    if ( strpos( $rpath, '/' ) !== 0 )
		$rpath = '/' . $rpath;
	} elseif ( strpos( $_SERVER['REQUEST_URI'], $dyapress_permalink ) === 1 ) {
	    error_log("dyapress_trigger begin time from permalink access: ".(microtime(true)-$_SERVER['REQUEST_TIME_FLOAT']));

	    require_once( dirname(__FILE__) . '/dyapress-compat.php' );

	    $ruri = substr( $_SERVER['REQUEST_URI'], strlen($dyapress_permalink)+1 );
	    if ( preg_match( '/(.*?)\.php/', $ruri, $matches) )
		$rpath = $matches[1];
	    else
		$rpath = parse_url( $ruri, PHP_URL_PATH );
	}

	if ( isset( $rpath) ) {
	    # if file exists with .php extensions, include it
	    if ( file_exists( DOL_DOCUMENT_ROOT . $rpath . ".php" ) ) {
		include DOL_DOCUMENT_ROOT . $rpath . ".php";
		error_log("dyapress_trigger (indirect php call to [$rpath]) end time: ".(microtime(true)-$_SERVER['REQUEST_TIME_FLOAT']));
		exit;
	    } elseif ( preg_match( '#^/api/#', $rpath ) ) {
		// FIXME: WordPress behaviour is not compatible with Restler expectation of URL, fix it
		$_SERVER['REQUEST_URI'] = preg_replace('#^/'.$dyapress_permalink.'/api#', '', $_SERVER['REQUEST_URI']);
		$_SERVER['REDIRECT_URL'] = preg_replace('#^/'.$dyapress_permalink.'/api#', '', $_SERVER['REDIRECT_URL']);
		include DOL_DOCUMENT_ROOT . '/api/index.php';
		error_log("dyapress_trigger (api call to [$rpath]) end time: ".(microtime(true)-$_SERVER['REQUEST_TIME_FLOAT']));
		exit;
	    } elseif ( preg_match( '/^\/webservices\//', $rpath ) ) {
		if ( file_exists( DOL_DOCUMENT_ROOT . $rpath ) ) {
		    include DOL_DOCUMENT_ROOT . $rpath;
		    error_log("dyapress_trigger (webservices call to [$rpath]) end time: ".(microtime(true)-$_SERVER['REQUEST_TIME_FLOAT']));
		    exit;
		}
	    } else {
		error_log("dyapress_trigger (no call to [$rpath]) end time: ".(microtime(true)-$_SERVER['REQUEST_TIME_FLOAT']));
	    }
	}
    }

    function dyapress_router() {
	// the following file defines all the various DyaPress globals (from Dolibarr) which need to be protected in WordPress
	include DOL_DOCUMENT_ROOT.'/dyapress-globals.php';

	if ( empty( $dyap_user ) || !current_user_can('read') )
	    wp_die( __( 'You do not have sufficient permissions to access this page.', 'dyapress' ) );

	if ( !isset( $dyap_user->id ) || $dyap_user->id == 0 ) {
	    $login=wp_get_current_user()->user_login;
	    $resultFetchUser=$dyap_user->fetch('',$login);

	    if ($resultFetchUser > 0)
		$dyap_user->getrights();
	}
	if ( !isset( $dyap_user->id ) || $dyap_user->id == 0 )
	    wp_die( __( 'You do not have sufficient permissions to access this page.', 'dyapress' ) );

	if ( isset( $_GET['mainmenu'] ) )
	    $_SESSION['mainmenu'] = sanitize_key( $_GET['mainmenu'] );
	elseif ( preg_match('/^dyap_(\w+)/', $_GET['page'], $matches) )
	    $_SESSION['mainmenu'] = $matches[1];

	if ( isset( $_GET['dyap_page'] ) )
	    $dyap_page = preg_replace( '/\/+/', '/', preg_replace( '/\.\.+/', '', $_GET['dyap_page'] ) );
	if ( empty( $dyap_page ) ) {
	    $screen = get_current_screen();

	    if ( isset($screen) && isset($screen->id) ) {
		if ( preg_match('/\bdyap_page=([\w\/]*)/', $this->page_hooks[$screen->id], $matches) )
                    $dyap_page = $matches[1];
                elseif ( preg_match('/^(.*)\.php\?/', $this->page_hooks[$screen->id], $matches) )
		    $dyap_page = $matches[1];

		if ( preg_match('/\bmainmenu=(\w*)/', $this->page_hooks[$screen->id], $matches) )
		    $_SESSION['mainmenu'] = $matches[1];
		if ( preg_match('/\bleftmenu=(\w*)/', $this->page_hooks[$screen->id], $matches) )
		    $_SESSION['leftmenu'] = $matches[1];
	    }
	}
	if ( empty( $dyap_page ) ) {
	    $_SESSION['mainmenu'] = 'home';
	    $_SESSION['leftmenu'] = 'setup';

	    $dyap_page = 'index';
	}

	global $dyap_ob_content;

	// keep track of already outputed content and continue with buffered output, in order for llxHeader to be fully functional
	$dyap_ob_content = ob_get_clean();
	ob_start();

	$page_content = '';
	if (file_exists(DOL_DOCUMENT_ROOT.$dyap_page.'.php')) {
	    include DOL_DOCUMENT_ROOT.$dyap_page.'.php';

	    $page_content = ob_get_clean();
	} else {
	    echo $dyap_ob_content;
	    echo '<div class="error"><p><strong>'.  __( 'The page of DyaPress you want to display does not exist.', 'dyapress' ).
		'</strong></p></div>';
	    $page_content = ob_get_clean();
	}
	echo $page_content;

	// FIX WordPress admin end-of-content which should not be printed
	global $dyap_output_llx_header;
	if ( empty( $dyap_output_llx_header ) || preg_match( '#/core/ajax/#', $dyap_page ) )
	    exit();
    }

    function get_class( $o ) {
	return preg_replace( '/^\x5c?DyaPress\x5c/i', '', get_class( $o ) );
    }

    function use_class( $c ) {
	return is_object( $c ) || preg_match( '/\x5c/', $c ) ? $c : '\\DyaPress\\'.$c;
    }

    function self_url() {
	$url = $_SERVER['PHP_SELF'];

	if ( isset( $_GET['page'] ) ) {
	    $url .= '?page='.esc_html( $_GET['page'] );
	    if ( isset( $_GET['dyap_page'] ) )
		$url .= '&dyap_page='.esc_html( $_GET['dyap_page'] );
	} elseif ( isset( $_GET['dyap_page'] ) )
	    $url .= '?dyap_page='.esc_html( $_GET['dyap_page'] );

	return $url;
    }

    function internal_url( $url = '' ) {
	return site_url( $this->dyapress_permalink() ) . $url;
    }

    function rewrite_url( $url ) {
	// Rewrite an url to match WordPress convention
	if ( $url == '/' ) {
            $result = admin_url( 'admin.php?page=dyap_home' );
        } elseif ( preg_match('/^\/?(document|viewimage)\.php/', $url) ) {
	    $result = $this->internal_url($url);
	} elseif ( preg_match('/\.(js|css)\.php/', $url) ) {
	    $result = $this->internal_url(preg_replace('/\.php/', '', $url));
	} elseif ( preg_match('/^.*\.php\?.*?\bmainmenu=(\w+)\b/', $url, $matches) && isset( $this->page_hooks['dyapress_page_dyap_'.$matches[1]]) ) {
	    $url = preg_replace('/\bmainmenu=(\w+)/', 'page=dyap_$1', $url);
	    $url = preg_replace('/^(.*)\.php\?/', '?dyap_page=$1&', $url);
	    $result = admin_url( 'admin.php' . $url );
	} elseif ( preg_match('/^.*\.php\?/', $url) ) {
	    $page = \DyaPress\GETPOST('page');
	    if ( $page == '' ) $page = 'dyap_home';
	    $url = preg_replace('/^(.*)\.php\?/', '?page='.$page.'&dyap_page=$1&', $url);
	    $result = admin_url( 'admin.php' . $url );
	} elseif ( preg_match('/^.*\.php$/', $url) ) {
	    $page = \DyaPress\GETPOST('page');
	    if ( $page == '' ) $page = 'dyap_home';
	    $url = preg_replace('/^(.*)\.php/', '?page='.$page.'&dyap_page=$1', $url);
	    $result = admin_url( 'admin.php' . $url );
	} else
	    $result = DOL_URL_ROOT.$url;

	return $result;
    }

    function rewrite_get_form( $url = '', $options = '' ) {
	// Rewrite a form to match WordPress convention for URL using method GET
	if ( empty( $url ) )
	    return '<form '.$options.' method="GET" action="'.admin_url( 'admin.php' ).'"><input type="hidden" name="page" value="'.esc_html( $_GET['page'] ).'"><input type="hidden" name="dyap_page" value="'.esc_html( $_GET['dyap_page'] ).'">';
	elseif ( preg_match('/^.*\.php$/', $url) )
	    return '<form '.$options.' method="GET" action="'.admin_url( 'admin.php' ).'"><input type="hidden" name="page" value="'.esc_html( $_GET['page'] ).'"><input type="hidden" name="dyap_page" value="'.esc_html( preg_replace('/^(.*)\.php/', '$1', $url) ).'">';
	else
	    return '<form '.$options.' method="GET" action="'.DOL_URL_ROOT.$url.'">';
    }

    function add_dyapress_menu() {
	global $dyap_conf, $dyap_db, $dyap_langs, $dyap_user, $dyap_mysoc, $dyap_hookmanager, $dyap_menumanager;
 
	if ( isset($_POST['dyapress_action']) || !isset($dyap_langs) ) {
	    add_menu_page( __( 'DyaPress dashboard', 'dyapress' ), __( 'DyaPress', 'dyapress' ), 'read', 'dyap_home', array( $this, 'dyapress_config' ), plugins_url( 'dyapress/img/menu_icon.png' ), 54 );
	    return false;
	}

	require_once( dirname(__FILE__) . '/dyapress-compat.php' );

	if ( !isset( $dyap_user->id ) || $dyap_user->id == 0 ) {
	    $login=wp_get_current_user()->user_login;
	    $resultFetchUser=$dyap_user->fetch('',$login);

	    if ($resultFetchUser > 0)
		$dyap_user->getrights();
	}
	if ( !isset( $dyap_user->id ) || $dyap_user->id == 0 ) {
	    add_menu_page( __( 'DyaPress dashboard', 'dyapress' ), __( 'DyaPress', 'dyapress' ), 'read', 'dyap_home', array( $this, 'dyapress_config' ), plugins_url( 'dyapress/img/menu_icon.png' ), 54 );
	    return false;
	}

	$dyap_langs->load("main");

	$this->page_hooks[ add_menu_page( __( 'DyaPress dashboard', 'dyapress' ), __( 'DyaPress', 'dyapress' ), 'read', 'dyap_home', array( $this, 'dyapress_router' ), plugins_url( 'dyapress/img/menu_icon.png' ), 54 ) ] = 'index.php?mainmenu=home&amp;leftmenu=home';

	$id = 'mainmenu';
	$usemenuhider = 1;
	$type_user = 0; // only a bakcoffice menu is displayed here
	$mode = 'top'; // $mode can be one of 'top', 'topnb', 'left', 'jmobile'
	$atarget = ''; // $atarget can be '' or '_top'
	$listofmodulesforexternal = explode(',', $dyap_conf->global->MAIN_MODULES_FOR_EXTERNAL);
	$main_url = preg_replace('/https?:\/\/[^\/]*/', '..', plugins_url( 'dyapress/index.php?mainmenu=home&amp;leftmenu=home' ) );
	$substitarray = \DyaPress\getCommonSubstitutionArray($dyap_langs, 0, null, null);

	require_once DOL_DOCUMENT_ROOT.'/core/lib/functions.lib.php';
	require_once DOL_DOCUMENT_ROOT.'/core/menus/standard/eldy.lib.php';
	require_once DOL_DOCUMENT_ROOT.'/core/class/menu.class.php';

	$dolmenu=new \DyaPress\Menu();

	// Show/Hide vertical menu. The hamburger icon for .menuhider action.
	if ($mode != 'jmobile' && $mode != 'topnb' && $usemenuhider && empty($dyap_conf->global->MAIN_OPTIMIZEFORTEXTBROWSER)) {
		$showmode = 1;
		$classname = 'class="tmenu menuhider"';
		$idsel = 'menu';

		$dolmenu->add('#', (!empty($dyap_conf->global->THEME_TOPMENU_DISABLE_IMAGE) ? '<span class="fa fa-bars"></span>' : ''), 0, $showmode, $atarget, "xxx", '', 0, $id, $idsel, $classname);
	}

	$menu_arr = array();

	// Home
	$menu_arr[] = array(
		'name' => 'Home',
		'link' => '/index.php?mainmenu=home&amp;leftmenu=home',
		'title' => "Home",
		'level' => 0,
		'enabled' => $showmode = 1,
		'target' => $atarget,
		'mainmenu' => "home",
		'leftmenu' => '',
		'position' => 10,
		'id' => $id,
		'idsel' => 'home',
		'classname' =>  $classname = (!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "home") ? 'class="tmenusel"' : 'class="tmenu"',
		'prefix' => '<span class="fa fa-home fa-fw paddingright"></span>',
		'session' => ((!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "home") ? 0 : 1),
		'loadLangs' => array(),
		'submenus' => array(),
	);

	// Members
	$tmpentry = array(
		'enabled' => (!empty($dyap_conf->adherent->enabled)),
		'perms' => (!empty($dyap_user->rights->adherent->lire)),
		'module' => 'adherent'
	);
	$menu_arr[] = array(
		'name' => 'Members',
		'link' => '/adherents/index.php?mainmenu=members&amp;leftmenu=',
		'title' => "MenuMembers",
		'level' => 0,
		'enabled' => $showmode = \DyaPress\isVisibleToUserType($type_user, $tmpentry, $listofmodulesforexternal),
		'target' => $atarget,
		'mainmenu' => "members",
		'leftmenu' => '',
		'position' => 18,
		'id' => $id,
		'idsel' => 'members',
		'classname' =>  $classname = (!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "members") ? 'class="tmenusel"' : 'class="tmenu"',
		'prefix' => \DyaPress\img_picto('', 'member', 'class="fa-fw paddingright"'),
		'session' => ((!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "members") ? 0 : 1),
		'loadLangs' => array(),
		'submenus' => array(),
	);

	// Third parties
	$tmpentry = array(
		'enabled'=> ((!empty($dyap_conf->societe->enabled) &&
			(empty($dyap_conf->global->SOCIETE_DISABLE_PROSPECTS) || empty($dyap_conf->global->SOCIETE_DISABLE_CUSTOMERS))
			)
			|| ((!empty($dyap_conf->fournisseur->enabled) && empty($dyap_conf->global->MAIN_USE_NEW_SUPPLIERMOD)) || !empty($dyap_conf->supplier_order->enabled) || !empty($dyap_conf->supplier_invoice->enabled))
			),
		'perms'=> (!empty($dyap_user->rights->societe->lire) || !empty($dyap_user->rights->fournisseur->lire) || !empty($dyap_user->rights->supplier_order->lire) || !empty($dyap_user->rights->supplier_invoice->lire) || !empty($dyap_user->rights->supplier_proposal->lire)),
		'module'=>'societe|fournisseur'
	);
	$menu_arr[] = array(
		'name' => 'Companies',
		'link' => '/societe/index.php?mainmenu=companies&amp;leftmenu=',
		'title' => "ThirdParties",
		'level' => 0,
		'enabled' => $showmode = \DyaPress\isVisibleToUserType($type_user, $tmpentry, $listofmodulesforexternal),
		'target' => $atarget,
		'mainmenu' => "companies",
		'leftmenu' => '',
		'position' => 20,
		'id' => $id,
		'idsel' => 'companies',
		'classname' =>  $classname = (!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "companies") ? 'class="tmenusel"' : 'class="tmenu"',
		'prefix' => \DyaPress\img_picto('', 'company', 'class="fa-fw paddingright"'),
		'session' => ((!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "companies") ? 0 : 1),
		'loadLangs' => array("companies", "suppliers"),
		'submenus' => array(),
	);

	// Products-Services
	$tmpentry = array(
		'enabled'=> (!empty($dyap_conf->product->enabled) || !empty($dyap_conf->service->enabled) || !empty($dyap_conf->expedition->enabled)),
		'perms'=> (!empty($dyap_user->rights->produit->lire) || !empty($dyap_user->rights->service->lire) || !empty($dyap_user->rights->expedition->lire)),
		'module'=>'product|service'
	);
	$menu_arr[] = array(
		'name' => 'Products',
		'link' => '/product/index.php?mainmenu=products&amp;leftmenu=',
		'title' => (!empty($dyap_conf->product->enabled) && !empty($dyap_conf->service->enabled))
					? (array("TMenuProducts", " | ", "TMenuServices"))
					: (!empty($dyap_conf->product->enabled) ? "TMenuProducts" : "TMenuServices"),
		'level' => 0,
		'enabled' => $showmode = \DyaPress\isVisibleToUserType($type_user, $tmpentry, $listofmodulesforexternal),
		'target' => $atarget,
		'mainmenu' => "products",
		'leftmenu' => '',
		'position' => 30,
		'id' => $id,
		'idsel' => 'products',
		'classname' =>  $classname = (!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "products") ? 'class="tmenusel"' : 'class="tmenu"',
		'prefix' => \DyaPress\img_picto('', 'product', 'class="fa-fw paddingright"'),
		'session' => ((!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "products") ? 0 : 1),
		'loadLangs' => array("products"),
		'submenus' => array(),
	);

	// MRP - GPAO
	$tmpentry = array(
		'enabled'=>(!empty($dyap_conf->bom->enabled) || !empty($dyap_conf->mrp->enabled)),
		'perms'=>(!empty($dyap_user->rights->bom->read) || !empty($dyap_user->rights->mrp->read)),
		'module'=>'bom|mrp'
	);
	$menu_arr[] = array(
		'name' => 'TMenuMRP',
		'link' => '/mrp/index.php?mainmenu=mrp&amp;leftmenu=',
		'title' => "TMenuMRP",
		'level' => 0,
		'enabled' => $showmode = \DyaPress\isVisibleToUserType($type_user, $tmpentry, $listofmodulesforexternal),
		'target' => $atarget,
		'mainmenu' => "mrp",
		'leftmenu' => '',
		'position' => 31,
		'id' => $id,
		'idsel' => 'mrp',
		'classname' =>  $classname = (!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "mrp") ? 'class="tmenusel"' : 'class="tmenu"',
		'prefix' => \DyaPress\img_picto('', 'mrp', 'class="fa-fw paddingright"'),
		'session' => ((!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "mrp") ? 0 : 1),
		'loadLangs' => array("mrp"),
		'submenus' => array(),
	);

	// Projects
	$tmpentry = array(
		'enabled'=> (!empty($dyap_conf->projet->enabled) ? 1 : 0),
		'perms'=> (!empty($dyap_user->rights->projet->lire) ? 1 : 0),
		'module'=>'projet'
	);
	$menu_arr[] = array(
		'name' => 'Projet',
		'link' => '/projet/index.php?mainmenu=project&amp;leftmenu=',
		'title' => (! empty($dyap_conf->global->PROJECT_USE_OPPORTUNITIES) && $dyap_conf->global->PROJECT_USE_OPPORTUNITIES == 2 ? "Leads" : "Projects"),
		'level' => 0,
		'enabled' => $showmode = \DyaPress\isVisibleToUserType($type_user, $tmpentry, $listofmodulesforexternal),
		'target' => $atarget,
		'mainmenu' => "project",
		'leftmenu' => '',
		'position' => 35,
		'id' => $id,
		'idsel' => 'project',
		'classname' =>  $classname = (!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "project") ? 'class="tmenusel"' : 'class="tmenu"',
		'prefix' => \DyaPress\img_picto('', 'project', 'class="fa-fw paddingright"'),
		'session' => ((!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "project") ? 0 : 1),
		'loadLangs' => array("projects"),
		'submenus' => array(),
	);

	// Commercial (propal, commande, supplier_proposal, supplier_order, contrat, ficheinter)
	$tmpentry = array(
		'enabled'=>(!empty($dyap_conf->propal->enabled)
			|| !empty($dyap_conf->commande->enabled)
			|| !empty($dyap_conf->fournisseur->enabled)
			|| !empty($dyap_conf->supplier_proposal->enabled)
			|| !empty($dyap_conf->supplier_order->enabled)
			|| !empty($dyap_conf->contrat->enabled)
			|| !empty($dyap_conf->ficheinter->enabled)
		) ? 1 : 0,
		'perms'=>(!empty($dyap_user->rights->propal->lire)
			|| !empty($dyap_user->rights->commande->lire)
			|| !empty($dyap_user->rights->supplier_proposal->lire)
			|| !empty($dyap_user->rights->fournisseur->lire)
			|| !empty($dyap_user->rights->fournisseur->commande->lire)
			|| !empty($dyap_user->rights->supplier_order->lire)
			|| !empty($dyap_user->rights->contrat->lire)
			|| !empty($dyap_user->rights->ficheinter->lire)
		),
		'module'=>'propal|commande|supplier_proposal|supplier_order|contrat|ficheinter'
	);

	$onlysupplierorder = !empty($dyap_user->rights->fournisseur->commande->lire) &&
		empty($dyap_user->rights->propal->lire) &&
		empty($dyap_user->rights->commande->lire) &&
		empty($dyap_user->rights->supplier_order->lire) &&
		empty($dyap_user->rights->supplier_proposal->lire) &&
		empty($dyap_user->rights->contrat->lire) &&
		empty($dyap_user->rights->ficheinter->lire);

	$menu_arr[] = array(
		'name' => 'Commercial',
		'link' => ($onlysupplierorder ? '/fourn/commande/index.php?mainmenu=commercial&amp;leftmenu=' : '/comm/index.php?mainmenu=commercial&amp;leftmenu='),
		'title' => "Commercial",
		'level' => 0,
		'enabled' => $showmode = \DyaPress\isVisibleToUserType($type_user, $tmpentry, $listofmodulesforexternal),
		'target' => $atarget,
		'mainmenu' => "commercial",
		'leftmenu' => '',
		'position' => 40,
		'id' => $id,
		'idsel' => 'commercial',
		'classname' =>  $classname = (!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "commercial") ? 'class="tmenusel"' : 'class="tmenu"',
		'prefix' => \DyaPress\img_picto('', 'contract', 'class="fa-fw paddingright"'),
		'session' => ((!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "commercial") ? 0 : 1),
		'loadLangs' => array("commercial"),
		'submenus' => array(),
	);

	// Billing - Financial
	$tmpentry = array(
		'enabled'=>(!empty($dyap_conf->facture->enabled) ||
			!empty($dyap_conf->don->enabled) ||
			!empty($dyap_conf->tax->enabled) ||
			!empty($dyap_conf->salaries->enabled) ||
			!empty($dyap_conf->supplier_invoice->enabled) ||
			!empty($dyap_conf->loan->enabled) ||
			!empty($dyap_conf->margins->enabled)
			) ? 1 : 0,
		'perms'=>(!empty($dyap_user->rights->facture->lire) || !empty($dyap_user->rights->don->contact->lire)
			|| !empty($dyap_user->rights->tax->charges->lire) || !empty($dyap_user->rights->salaries->read)
			|| !empty($dyap_user->rights->fournisseur->facture->lire) || !empty($dyap_user->rights->loan->read) || !empty($dyap_user->rights->margins->liretous)),
		'module'=>'facture|supplier_invoice|don|tax|salaries|loan'
	);
	$menu_arr[] = array(
		'name' => 'Compta',
		'link' => '/compta/index.php?mainmenu=billing&amp;leftmenu=',
		'title' =>  "MenuFinancial",
		'level' => 0,
		'enabled' => $showmode = \DyaPress\isVisibleToUserType($type_user, $tmpentry, $listofmodulesforexternal),
		'target' => $atarget,
		'mainmenu' => "billing",
		'leftmenu' => '',
		'position' => 50,
		'id' => $id,
		'idsel' => 'billing',
		'classname' =>  $classname = (!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "billing") ? 'class="tmenusel"' : 'class="tmenu"',
		'prefix' => \DyaPress\img_picto('', 'bill', 'class="fa-fw paddingright"'),
		'session' => ((!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "billing") ? 0 : 1),
		'loadLangs' => array("compta"),
		'submenus' => array(),
	);

	// Bank
	$tmpentry = array(
		'enabled'=>(!empty($dyap_conf->banque->enabled) || !empty($dyap_conf->prelevement->enabled)),
		'perms'=>(!empty($dyap_user->rights->banque->lire) || !empty($dyap_user->rights->prelevement->lire) || !empty($dyap_user->rights->paymentbybanktransfer->read)),
		'module'=>'banque|prelevement|paymentbybanktransfer'
	);
	$menu_arr[] = array(
		'name' => 'Bank',
		'link' => '/compta/bank/list.php?mainmenu=bank&amp;leftmenu=',
		'title' =>  "MenuBankCash",
		'level' => 0,
		'enabled' => $showmode = \DyaPress\isVisibleToUserType($type_user, $tmpentry, $listofmodulesforexternal),
		'target' => $atarget,
		'mainmenu' => "bank",
		'leftmenu' => '',
		'position' => 52,
		'id' => $id,
		'idsel' => 'bank',
		'classname' =>  $classname = (!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "bank") ? 'class="tmenusel"' : 'class="tmenu"',
		'prefix' => \DyaPress\img_picto('', 'bank_account', 'class="fa-fw paddingright"'),
		'session' => ((!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "bank") ? 0 : 1),
		'loadLangs' => array("compta", "banks"),
		'submenus' => array(),
	);

	// Accounting
	$tmpentry = array(
		'enabled'=>(!empty($dyap_conf->comptabilite->enabled) || !empty($dyap_conf->accounting->enabled) || !empty($dyap_conf->asset->enabled) || !empty($dyap_conf->intracommreport->enabled)),
		'perms'=>(!empty($dyap_user->rights->compta->resultat->lire) || !empty($dyap_user->rights->accounting->comptarapport->lire) || !empty($dyap_user->rights->accounting->mouvements->lire) || !empty($dyap_user->rights->asset->read) || !empty($dyap_user->rights->intracommreport->read)),
		'module'=>'comptabilite|accounting|asset|intracommreport'
	);
	$menu_arr[] = array(
		'name' => 'Accounting',
		'link' => '/accountancy/index.php?mainmenu=accountancy&amp;leftmenu=',
		'title' =>  "MenuAccountancy",
		'level' => 0,
		'enabled' => $showmode = \DyaPress\isVisibleToUserType($type_user, $tmpentry, $listofmodulesforexternal),
		'target' => $atarget,
		'mainmenu' => "accountancy",
		'leftmenu' => '',
		'position' => 54,
		'id' => $id,
		'idsel' => 'accountancy',
		'classname' =>  $classname = (!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "accountancy") ? 'class="tmenusel"' : 'class="tmenu"',
		'prefix' => \DyaPress\img_picto('', 'accountancy', 'class="fa-fw paddingright"'),
		'session' => ((!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "accountancy") ? 0 : 1),
		'loadLangs' => array("compta", "accountancy", "assets", "intracommreport"),
		'submenus' => array(),
	);

	// HRM
	$tmpentry = array(
		'enabled'=>(!empty($dyap_conf->hrm->enabled) || (!empty($dyap_conf->holiday->enabled)) || !empty($dyap_conf->deplacement->enabled) || !empty($dyap_conf->expensereport->enabled) || !empty($dyap_conf->recruitment->enabled)),
		'perms'=>(!empty($dyap_user->rights->user->user->lire) || !empty($dyap_user->rights->holiday->read) || !empty($dyap_user->rights->deplacement->lire) || !empty($dyap_user->rights->expensereport->lire) || !empty($dyap_user->rights->recruitment->recruitmentjobposition->read)),
		'module'=>'hrm|holiday|deplacement|expensereport|recruitment'
	);

	$menu_arr[] = array(
		'name' => 'HRM',
		'link' => '/hrm/index.php?mainmenu=hrm&amp;leftmenu=',
		'title' =>  "HRM",
		'level' => 0,
		'enabled' => $showmode = \DyaPress\isVisibleToUserType($type_user, $tmpentry, $listofmodulesforexternal),
		'target' => $atarget,
		'mainmenu' => "hrm",
		'leftmenu' => '',
		'position' => 80,
		'id' => $id,
		'idsel' => 'hrm',
		'classname' =>  $classname = (!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "hrm") ? 'class="tmenusel"' : 'class="tmenu"',
		'prefix' => \DyaPress\img_picto('', 'hrm', 'class="fa-fw paddingright"'),
		'session' => ((!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "hrm") ? 0 : 1),
		'loadLangs' => array("holiday"),
		'submenus' => array(),
	);

	// Tickets and knowledge base
	$tmpentry = array(
		'enabled'=>(!empty($dyap_conf->ticket->enabled) || !empty($dyap_conf->knowledgemanagement->enabled)),
		'perms'=>(!empty($dyap_user->rights->ticket->read) || !empty($dyap_user->rights->knowledgemanagement->knowledgerecord->read)),
		'module'=>'ticket|knowledgemanagement'
	);
	$link = '';
	if (!empty($dyap_conf->ticket->enabled)) {
		$link = '/ticket/index.php?mainmenu=ticket&amp;leftmenu=';
	} else {
		$link = '/knowledgemanagement/knowledgerecord_list.php?mainmenu=ticket&amp;leftmenu=';
	}
	$menu_arr[] = array(
		'name' => 'Ticket',
		'link' => '/ticket/index.php?mainmenu=ticket&amp;leftmenu=',
		'title' =>  "Tickets",
		'level' => 0,
		'enabled' => $showmode = \DyaPress\isVisibleToUserType($type_user, $tmpentry, $listofmodulesforexternal),
		'target' => $atarget,
		'mainmenu' => "ticket",
		'leftmenu' => '',
		'position' => 88,
		'id' => $id,
		'idsel' => 'ticket',
		'classname' =>  $classname = (!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "ticket") ? 'class="tmenusel"' : 'class="tmenu"',
		'prefix' => \DyaPress\img_picto('', 'ticket', 'class="fa-fw paddingright"'),
		'session' => ((!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "ticket") ? 0 : 1),
		'loadLangs' => array("other"),
		'submenus' => array(),
	);

	// Tools
	$tmpentry = array(
		'enabled'=>1,
		'perms'=>1,
		'module'=>''
	);
	$menu_arr[] = array(
		'name' => 'Tools',
		'link' => '/core/tools.php?mainmenu=tools&amp;leftmenu=',
		'title' =>  "Tools",
		'level' => 0,
		'enabled' => $showmode = \DyaPress\isVisibleToUserType($type_user, $tmpentry, $listofmodulesforexternal),
		'target' => $atarget,
		'mainmenu' => "tools",
		'leftmenu' => '',
		'position' => 90,
		'id' => $id,
		'idsel' => 'tools',
		'classname' =>  $classname = (!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "tools") ? 'class="tmenusel"' : 'class="tmenu"',
		'prefix' => \DyaPress\img_picto('', 'tools', 'class="fa-fw paddingright"'),
		'session' => ((!empty($_SESSION["mainmenu"]) && $_SESSION["mainmenu"] == "tools") ? 0 : 1),
		'loadLangs' => array("other"),
		'submenus' => array(),
	);

	// Add menus
	foreach ($menu_arr as $key => $smenu) {
		$smenu = (object) $smenu;

		if ($smenu->enabled) {
			if ($smenu->session) {
				$_SESSION['idmenu'] = '';
			}

			// Load Langue
			if (!empty($smenu->loadLangs)) {
				$dyap_langs->loadLangs($smenu->loadLangs);
			}

			// Trans title
			$mtitle = '';
			if (is_array($smenu->title)) {
				foreach ($smenu->title as $item) {
					$mtitle .= $dyap_langs->trans($item);
				}
			} else {
				$mtitle = $dyap_langs->trans($smenu->title);
			}
			// Add item
			$dolmenu->add($smenu->link, $mtitle, $smenu->level, $smenu->enabled, $smenu->target, $smenu->mainmenu, $smenu->leftmenu, $smenu->position, $smenu->id, $smenu->idsel, $smenu->classname, $smenu->prefix);
		}
	}

	// Show personalized menus
	$menuArbo = new \DyaPress\Menubase($dyap_db, 'eldy');

	$tabMenu = $dyap_menumanager->tabMenu;
	$newTabMenu = $menuArbo->menuTopCharger('', '', $type_user, 'eldy', $tabMenu); // Return tabMenu with only top entries

	$num = count($newTabMenu);
	for ($i = 0; $i < $num; $i++) {
		//var_dump($type_user.' '.$newTabMenu[$i]['url'].' '.$showmode.' '.$newTabMenu[$i]['perms']);
		$idsel = (empty($newTabMenu[$i]['mainmenu']) ? 'none' : $newTabMenu[$i]['mainmenu']);

		$newTabMenu[$i]['url'] = \DyaPress\make_substitutions($newTabMenu[$i]['url'], $substitarray);

		// url = url from host, shorturl = relative path into dolibarr sources
		$url = $shorturl = $newTabMenu[$i]['url'];
		if (!preg_match("/^(http:\/\/|https:\/\/)/i", $newTabMenu[$i]['url'])) {	// Do not change url content for external links
			$tmp = explode('?', $newTabMenu[$i]['url'], 2);
			$url = $shorturl = $tmp[0];
			$param = (isset($tmp[1]) ? $tmp[1] : '');

			if (!preg_match('/mainmenu/i', $param) || !preg_match('/leftmenu/i', $param)) {
				$param .= ($param ? '&' : '').'mainmenu='.$newTabMenu[$i]['mainmenu'].'&amp;leftmenu=';
			}
			//$url.="idmenu=".$newTabMenu[$i]['rowid'];    // Already done by menuLoad
			$url = \DyaPress\dol_buildpath($url, 1).($param ? '&'.$param : ''); // FIXME: ? is never needed but only &
			//$shorturl = $shorturl.($param?'?'.$param:'');
			$shorturl = $url;
			if (DOL_URL_ROOT) {
				$shorturl = preg_replace('/^'.preg_quote(DOL_URL_ROOT, '/').'/', '', $shorturl);
			}
		}

		$showmode = \DyaPress\isVisibleToUserType($type_user, $newTabMenu[$i], $listofmodulesforexternal);
		if ($showmode == 1) {
			// Define the class (top menu selected or not)
			if (!empty($_SESSION['idmenu']) && $newTabMenu[$i]['rowid'] == $_SESSION['idmenu']) {
				$classname = 'class="tmenusel"';
			} elseif (!empty($_SESSION["mainmenu"]) && $newTabMenu[$i]['mainmenu'] == $_SESSION["mainmenu"]) {
				$classname = 'class="tmenusel"';
			} else {
				$classname = 'class="tmenu"';
			}
		} elseif ($showmode == 2) {
			$classname = 'class="tmenu"';
		}

		$dolmenu->add(
			$shorturl,
			$newTabMenu[$i]['titre'],
			0,
			$showmode,
			($newTabMenu[$i]['target'] ? $newTabMenu[$i]['target'] : $atarget),
			($newTabMenu[$i]['mainmenu'] ? $newTabMenu[$i]['mainmenu'] : $newTabMenu[$i]['rowid']),
			($newTabMenu[$i]['leftmenu'] ? $newTabMenu[$i]['leftmenu'] : ''),
			$newTabMenu[$i]['position'],
			$id,
			$idsel,
			$classname,
			$newTabMenu[$i]['prefix']
		);
	}

	// Sort on position
	$dolmenu->liste = \DyaPress\dol_sort_array($dolmenu->liste, 'position');

	// Add menu entries
	// Try avoiding multiple output by allowing only one position
	$position = 0;
	foreach($dolmenu->liste as $menkey => $menuval)
	{
	    if ( $position < $menuval['position'] ) {
		$this->page_hooks[ add_submenu_page( 'dyap_home', $menuval['titre'], $menuval['titre'], 'read', 'dyap_'.$menuval['mainmenu'], array( $this, 'dyapress_router' ) ) ] = $menuval['url']; // plugins_url( 'dyapress'.$menuval['url'] );
		$position = $menuval['position'];
	    }
	}

	if ( $this->check_licence() < time() ) {
	    global $submenu;

	    // add Upgrade to Premium link
	    $submenu['dyap_home'][] = array( '<strong style="color: #4096dd">'. __( 'Upgrade to Premium', 'dyapress') .'</strong>', 'activate_plugins', ( preg_match( '/fr_/', get_locale() ) ? 'https://dyapress.fr/inscription' : 'https://dyapress.com/signup' ), '', '' );
	}

	return true;
    }

    function dyapress_bufferize( $screen ) {
	/*
	foreach( $GLOBALS['wp_actions'] as $dyap_action => $count )
		   printf( '%s (%d) <br/>' . PHP_EOL, $dyap_action, $count );

	print_r("hook=$hook, page_hook=");print_r($this->page_hooks);
	 */
	if ( isset($screen) && isset($screen->id) && isset( $this->page_hooks[$screen->id] ) )
	    ob_start();
    }

    function add_dyapress_scripts( $hook ) {
	if ( isset($_POST['dyapress_action']) || ! isset( $this->page_hooks[$hook] ) )
	    return;

	require_once( dirname(__FILE__) . '/dyapress-init.php' );

	global $dyap_db, $dyap_conf, $dyap_langs, $dyap_user, $dyap_hookmanager;

	if (empty($dyap_conf->css)) $dyap_conf->css = '/theme/eldy/style.css.php';

	if ( ! file_exists( DOL_DOCUMENT_ROOT . $dyap_conf->css ) )
	    return;

	if (!is_object($dyap_hookmanager)) {
	    $dyap_hookmanager = new \DyaPress\HookManager($dyap_db);
	}
	$dyap_hookmanager->initHooks(array("main"));

	$version = \DyaPress\GETPOST('version', 'int'); // usefull to force no cache on css/js
	$ext = '?layout='.$dyap_conf->browser->layout.'&amp;version='.($version  ? $version : urlencode(DYAPRESS_VERSION) );

	/* DyaPress following code suppressed from original Dolibarr :
	if (GETPOST('dol_basehref', 'alpha')) {
	    print '<base href="'.dol_escape_htmltag(GETPOST('dol_basehref', 'alpha')).'">'."\n";
	}

	// Displays meta
	print '<meta charset="utf-8">'."\n";
	print '<meta name="robots" content="noindex'.($disablenofollow ? '' : ',nofollow').'">'."\n"; // Do not index
	print '<meta name="viewport" content="width=device-width, initial-scale=1.0">'."\n"; // Scale for mobile device
	print '<meta name="author" content="Dolibarr Development Team">'."\n";
	if (getDolGlobalInt('MAIN_FEATURES_LEVEL')) {
	    print '<meta name="MAIN_FEATURES_LEVEL" content="'.getDolGlobalInt('MAIN_FEATURES_LEVEL').'">'."\n";
	}
	// Favicon
	$favicon = DOL_URL_ROOT.'/theme/dolibarr_256x256_color.png';
	if (!empty($mysoc->logo_squarred_mini)) {
	    $favicon = DOL_URL_ROOT.'/viewimage.php?cache=1&modulepart=mycompany&file='.urlencode('logos/thumbs/'.$mysoc->logo_squarred_mini);
	}
	if (!empty($dyap_conf->global->MAIN_FAVICON_URL)) {
	    $favicon = $dyap_conf->global->MAIN_FAVICON_URL;
	}
	if (empty($dyap_conf->dol_use_jmobile)) {
	    print '<link rel="shortcut icon" type="image/x-icon" href="'.$favicon.'"/>'."\n"; // Not required into an Android webview
	}

	//if (empty($dyap_conf->global->MAIN_OPTIMIZEFORTEXTBROWSER)) print '<link rel="top" title="'.$langs->trans("Home").'" href="'.(DOL_URL_ROOT?DOL_URL_ROOT:'/').'">'."\n";
	//if (empty($dyap_conf->global->MAIN_OPTIMIZEFORTEXTBROWSER)) print '<link rel="copyright" title="GNU General Public License" href="https://www.gnu.org/copyleft/gpl.html#SEC1">'."\n";
	//if (empty($dyap_conf->global->MAIN_OPTIMIZEFORTEXTBROWSER)) print '<link rel="author" title="Dolibarr Development Team" href="https://www.dolibarr.org">'."\n";

	// Mobile appli like icon
	$manifest = DOL_URL_ROOT.'/theme/'.$dyap_conf->theme.'/manifest.json.php';
	if (!empty($manifest)) {
	    print '<link rel="manifest" href="'.$manifest.'" />'."\n";
	}

	if (!empty($dyap_conf->global->THEME_ELDY_TOPMENU_BACK1)) {
	    // TODO: use auto theme color switch
	    print '<meta name="theme-color" content="rgb('.$dyap_conf->global->THEME_ELDY_TOPMENU_BACK1.')">'."\n";
	}

	// Auto refresh page
	if (GETPOST('autorefresh', 'int') > 0) {
	    print '<meta http-equiv="refresh" content="'.GETPOST('autorefresh', 'int').'">';
	}

	// Displays title
	$appli = constant('DOL_APPLICATION_TITLE');
	if (!empty($dyap_conf->global->MAIN_APPLICATION_TITLE)) {
	    $appli = $dyap_conf->global->MAIN_APPLICATION_TITLE;
	}

	print '<title>';
	$titletoshow = '';
	if ($title && !empty($dyap_conf->global->MAIN_HTML_TITLE) && preg_match('/noapp/', $dyap_conf->global->MAIN_HTML_TITLE)) {
	    $titletoshow = dol_htmlentities($title);
	} elseif ($title) {
	    $titletoshow = dol_htmlentities($appli.' - '.$title);
	} else {
	    $titletoshow = dol_htmlentities($appli);
	}

	$parameters = array('title'=>$titletoshow);
	$result = $hookmanager->executeHooks('setHtmlTitle', $parameters); // Note that $action and $object may have been modified by some hooks
	if ($result > 0) {
	    $titletoshow = $hookmanager->resPrint; // Replace Title to show
	} else {
	    $titletoshow .= $hookmanager->resPrint; // Concat to Title to show
	}

	print $titletoshow;
	print '</title>';

	print "\n";
	 */

	$disablejs = false;
	$arrayofcss = array();
	$arrayofjs = array();

	$optioncss = \DyaPress\GETPOST('optioncss', 'aZ09', 1);
	$themeparam = '?lang='.$dyap_langs->defaultlang.'&amp;theme='.$dyap_conf->theme.($optioncss ? '&amp;optioncss='.$optioncss : '').'&amp;userid='.$dyap_user->id.'&amp;entity='.$dyap_conf->entity;
	$themeparam .= ($ext ? '&amp;'.$ext : '').'&amp;revision='.\DyaPress\getDolGlobalInt("MAIN_IHM_PARAMS_REV");
	if (!empty($_SESSION['dol_resetcache'])) {
	    $themeparam .= '&amp;dol_resetcache='.$_SESSION['dol_resetcache'];
	}
	if (\DyaPress\GETPOSTISSET('dol_hide_topmenu')) {
	    $themeparam .= '&amp;dol_hide_topmenu='.\DyaPress\GETPOST('dol_hide_topmenu', 'int');
	}
	if (\DyaPress\GETPOSTISSET('dol_hide_leftmenu')) {
	    $themeparam .= '&amp;dol_hide_leftmenu='.\DyaPress\GETPOST('dol_hide_leftmenu', 'int');
	}
	if (\DyaPress\GETPOSTISSET('dol_optimize_smallscreen')) {
	    $themeparam .= '&amp;dol_optimize_smallscreen='.\DyaPress\GETPOST('dol_optimize_smallscreen', 'int');
	}
	if (\DyaPress\GETPOSTISSET('dol_no_mouse_hover')) {
	    $themeparam .= '&amp;dol_no_mouse_hover='.\DyaPress\GETPOST('dol_no_mouse_hover', 'int');
	}
	if (\DyaPress\GETPOSTISSET('dol_use_jmobile')) {
	    $themeparam .= '&amp;dol_use_jmobile='.\DyaPress\GETPOST('dol_use_jmobile', 'int'); $dyap_conf->dol_use_jmobile = \DyaPress\GETPOST('dol_use_jmobile', 'int');
	}
	if (\DyaPress\GETPOSTISSET('THEME_DARKMODEENABLED')) {
	    $themeparam .= '&amp;THEME_DARKMODEENABLED='.\DyaPress\GETPOST('THEME_DARKMODEENABLED', 'int');
	}
	if (\DyaPress\GETPOSTISSET('THEME_SATURATE_RATIO')) {
	    $themeparam .= '&amp;THEME_SATURATE_RATIO='.\DyaPress\GETPOST('THEME_SATURATE_RATIO', 'int');
	}

	if (!empty($dyap_conf->global->MAIN_ENABLE_FONT_ROBOTO)) {
	    // DyaPress code removed: print '<link rel="preconnect" href="https://fonts.gstatic.com">'."\n";
	    /* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
	    print '<link href="https://fonts.googleapis.com/css2?family=Roboto:wght@200;300;400;500;600&display=swap" rel="stylesheet">'."\n";
	     */
	    wp_enqueue_style( 'fonts-googleapis-roboto', "https://fonts.googleapis.com/css2?family=Roboto:wght@200;300;400;500;600&display=swap", array(), null );
	}

	if (!defined('DISABLE_JQUERY') && !$disablejs && $dyap_conf->use_javascript_ajax) {
	    // DyaPress code removed: print '<!-- Includes CSS for JQuery (Ajax library) -->'."\n";
	    $jquerytheme = 'base';
	    if (!empty($dyap_conf->global->MAIN_USE_JQUERY_THEME)) {
		$jquerytheme = $dyap_conf->global->MAIN_USE_JQUERY_THEME;
	    }
	    if (constant('JS_JQUERY_UI')) {
		/* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
		print '<link rel="stylesheet" type="text/css" href="'.JS_JQUERY_UI.'css/'.$jquerytheme.'/jquery-ui.min.css'.($ext ? '?'.$ext : '').'">'."\n"; // Forced JQuery
		 */
		wp_enqueue_style( 'dyapress-jquery-ui', JS_JQUERY_UI.'css/'.$jquerytheme.'/jquery-ui.min.css'.$ext, array(), null );
	    } else {
		/* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
		print '<link rel="stylesheet" type="text/css" href="'.DOL_URL_ROOT.'/includes/jquery/css/'.$jquerytheme.'/jquery-ui.css'.($ext ? '?'.$ext : '').'">'."\n"; // JQuery
		 */
		wp_enqueue_style( 'dyapress-jquery-ui', DOL_URL_ROOT.'/includes/jquery/css/'.$jquerytheme.'/jquery-ui.css'.$ext, array(), null );
	    }
	    if (!defined('DISABLE_JQUERY_JNOTIFY')) {
		/* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
		print '<link rel="stylesheet" type="text/css" href="'.DOL_URL_ROOT.'/includes/jquery/plugins/jnotify/jquery.jnotify-alt.min.css'.($ext ? '?'.$ext : '').'">'."\n"; // JNotify
		 */
		wp_enqueue_style( 'dyapress-jquery-jnotify', DOL_URL_ROOT.'/includes/jquery/plugins/jnotify/jquery.jnotify-alt.min.css'.$ext, array(), null );
	    }
	    if (!defined('DISABLE_SELECT2') && (!empty($dyap_conf->global->MAIN_USE_JQUERY_MULTISELECT) || defined('REQUIRE_JQUERY_MULTISELECT'))) {     // jQuery plugin "mutiselect", "multiple-select", "select2"...
		$tmpplugin = empty($dyap_conf->global->MAIN_USE_JQUERY_MULTISELECT) ?constant('REQUIRE_JQUERY_MULTISELECT') : $dyap_conf->global->MAIN_USE_JQUERY_MULTISELECT;
		/* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
		print '<link rel="stylesheet" type="text/css" href="'.DOL_URL_ROOT.'/includes/jquery/plugins/'.$tmpplugin.'/dist/css/'.$tmpplugin.'.css'.($ext ? '?'.$ext : '').'">'."\n";
		 */
		wp_enqueue_style( 'dyapress-jquery-multiselect', DOL_URL_ROOT.'/includes/jquery/plugins/'.$tmpplugin.'/dist/css/'.$tmpplugin.'.css'.$ext, array(), null );
	    }
	}

	if (!defined('DISABLE_FONT_AWSOME')) {
	    // DyaPress code removed: print '<!-- Includes CSS for font awesome -->'."\n";
	    /* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
	    print '<link rel="stylesheet" type="text/css" href="'.DOL_URL_ROOT.'/theme/common/fontawesome-5/css/all.min.css'.($ext ? '?'.$ext : '').'">'."\n";
	    print '<link rel="stylesheet" type="text/css" href="'.DOL_URL_ROOT.'/theme/common/fontawesome-5/css/v4-shims.min.css'.($ext ? '?'.$ext : '').'">'."\n";
	     */
	    wp_enqueue_style( 'dyapress-fontawesome-all', DOL_URL_ROOT.'/theme/common/fontawesome-5/css/all.min.css'.$ext, array(), null );
	    wp_enqueue_style( 'dyapress-fontawesome-v4-shims', DOL_URL_ROOT.'/theme/common/fontawesome-5/css/v4-shims.min.css'.$ext, array(), null );
	}

	// DyaPress code removed: print '<!-- Includes CSS for Dolibarr theme -->'."\n";
	// Output style sheets (optioncss='print' or ''). Note: $dyap_conf->css looks like '/theme/eldy/style.css.php'
	$themepath = dyap_url($dyap_conf->css);
	$themesubdir = '';
	if (!empty($dyap_conf->modules_parts['theme'])) {	// This slow down
	    foreach ($dyap_conf->modules_parts['theme'] as $reldir) {
		if (file_exists(dol_buildpath($reldir.$dyap_conf->css, 0))) {
		    $themepath = dol_buildpath($reldir.$dyap_conf->css, 1);
		    $themesubdir = $reldir;
		    break;
		}
	    }
	}

	//print 'themepath='.$themepath.' themeparam='.$themeparam;exit;
	/* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
	print '<link rel="stylesheet" type="text/css" href="'.$themepath.$themeparam.'">'."\n";
	 */
	wp_enqueue_style( 'dyapress-theme', $themepath.$themeparam, array(), DYAPRESS_VERSION );
	/* DyaPress: code removed :
	if (!empty($dyap_conf->global->MAIN_FIX_FLASH_ON_CHROME)) {
	    print '<!-- Includes CSS that does not exists as a workaround of flash bug of chrome -->'."\n".'<link rel="stylesheet" type="text/css" href="filethatdoesnotexiststosolvechromeflashbug">'."\n";
	}
	 */

	// CSS forced by modules (relative url starting with /)
	if (!empty($dyap_conf->modules_parts['css'])) {
	    $arraycss = (array) $dyap_conf->modules_parts['css'];
	    foreach ($arraycss as $modcss => $filescss) {
		$filescss = (array) $filescss; // To be sure filecss is an array
		foreach ($filescss as $cssfile) {
		    if (empty($cssfile)) {
			dol_syslog("Warning: module ".$modcss." declared a css path file into its descriptor that is empty.", LOG_WARNING);
		    }
		    // cssfile is a relative path
		    $urlforcss = dol_buildpath($cssfile, 1);
		    if ($urlforcss && $urlforcss != '/') {
			/* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
			print '<!-- Includes CSS added by module '.$modcss.' -->'."\n".'<link rel="stylesheet" type="text/css" href="'.$urlforcss;
			// We add params only if page is not static, because some web server setup does not return content type text/css if url has parameters, so browser cache is not used.
			if (!preg_match('/\.css$/i', $cssfile)) {
			    print $themeparam;
			}
			print '">'."\n";
			 */
			wp_enqueue_style( 'dyapress-module-'.$modcss, $urlforcss.(!preg_match('/\.css$/i', $cssfile) ? $themeparam : ''), array(), null);
		    } else {
			dol_syslog("Warning: module ".$modcss." declared a css path file for a file we can't find.", LOG_WARNING);
		    }
		}
	    }
	}
	// CSS forced by page in top_htmlhead call (relative url starting with /)
	if (is_array($arrayofcss)) {
	    $i = 1;
	    foreach ($arrayofcss as $cssfile) {
		if (preg_match('/^(http|\/\/)/i', $cssfile)) {
		    $urltofile = $cssfile;
		} else {
		    $urltofile = dol_buildpath($cssfile, 1);
		}
		/* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
		print '<!-- Includes CSS added by page -->'."\n".'<link rel="stylesheet" type="text/css" title="default" href="'.$urltofile;
		// We add params only if page is not static, because some web server setup does not return content type text/css if url has parameters and browser cache is not used.
		if (!preg_match('/\.css$/i', $cssfile)) {
		    print $themeparam;
		}
		print '">'."\n";
		 */
		wp_enqueue_style( 'dyapress-arrayofcss-'.$i++, $urltofile.(!preg_match('/\.css$/i', $cssfile) ? $themeparam : ''), array(), null);
	    }
	}

	// Output standard javascript links
	if (!defined('DISABLE_JQUERY') && !$disablejs && !empty($dyap_conf->use_javascript_ajax)) {
	    // JQuery. Must be before other includes
	    /* DyaPress: code migrated to WordPress and using WordPress base instead of Dolibarr origin :
	    print '<!-- Includes JS for JQuery -->'."\n";
	    if (defined('JS_JQUERY') && constant('JS_JQUERY')) {
		print '<script src="'.JS_JQUERY.'jquery.min.js'.($ext ? '?'.$ext : '').'"></script>'."\n";
	    } else {
		print '<script src="'.DOL_URL_ROOT.'/includes/jquery/js/jquery.min.js'.($ext ? '?'.$ext : '').'"></script>'."\n";
	    }
	     */
	    wp_enqueue_script( 'jquery' );
	    /* DyaPress: code migrated to WordPress and using WordPress base instead of Dolibarr origin :
	    if (defined('JS_JQUERY_UI') && constant('JS_JQUERY_UI')) {
		print '<script src="'.JS_JQUERY_UI.'jquery-ui.min.js'.($ext ? '?'.$ext : '').'"></script>'."\n";
	    } else {
		print '<script src="'.DOL_URL_ROOT.'/includes/jquery/js/jquery-ui.min.js'.($ext ? '?'.$ext : '').'"></script>'."\n";
	    }
	     */
	    wp_enqueue_script( 'jquery-ui-core' );
	    wp_enqueue_script( 'jquery-ui-dialog' );
	    wp_enqueue_script( 'jquery-ui-widget' );
	    wp_enqueue_script( 'jquery-ui-tooltip' );
	    wp_enqueue_script( 'jquery-ui-sortable' );
	    wp_enqueue_script( 'jquery-ui-datepicker' );
	    wp_enqueue_script( 'jquery-ui-autocomplete' );
	    if (!defined('DISABLE_JQUERY_TABLEDND')) {
		/* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
		print '<script src="'.DOL_URL_ROOT.'/includes/jquery/plugins/tablednd/jquery.tablednd.min.js'.($ext ? '?'.$ext : '').'"></script>'."\n";
		 */
		wp_enqueue_script( 'dyapress-jquery-tablednd', DOL_URL_ROOT.'/includes/jquery/plugins/tablednd/jquery.tablednd.min.js'.$ext, array( 'jquery-ui-widget' ), null );
	    }
	    // jQuery jnotify
	    if (empty($dyap_conf->global->MAIN_DISABLE_JQUERY_JNOTIFY) && !defined('DISABLE_JQUERY_JNOTIFY')) {
		/* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
		print '<script src="'.DOL_URL_ROOT.'/includes/jquery/plugins/jnotify/jquery.jnotify.min.js'.($ext ? '?'.$ext : '').'"></script>'."\n";
		 */
		wp_enqueue_script( 'dyapress-jquery-jnotify', DOL_URL_ROOT.'/includes/jquery/plugins/jnotify/jquery.jnotify.min.js'.$ext, array( 'jquery-ui-widget' ), null );
	    }
	    // Chart
	    if ((empty($dyap_conf->global->MAIN_JS_GRAPH) || $dyap_conf->global->MAIN_JS_GRAPH == 'chart') && !defined('DISABLE_JS_GRAPH')) {
		/* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
		print '<script src="'.DOL_URL_ROOT.'/includes/nnnick/chartjs/dist/chart.min.js'.($ext ? '?'.$ext : '').'"></script>'."\n";
		 */
		wp_enqueue_script( 'dyapress-jquery-chartjs', DOL_URL_ROOT.'/includes/nnnick/chartjs/dist/chart.min.js'.$ext, array( 'jquery-ui-widget' ), null );
	    }

	    // jQuery jeditable for Edit In Place features
	    if (!empty($dyap_conf->global->MAIN_USE_JQUERY_JEDITABLE) && !defined('DISABLE_JQUERY_JEDITABLE')) {
		/* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
		print '<!-- JS to manage editInPlace feature -->'."\n";
		print '<script src="'.DOL_URL_ROOT.'/includes/jquery/plugins/jeditable/jquery.jeditable.js'.($ext ? '?'.$ext : '').'"></script>'."\n";
		print '<script src="'.DOL_URL_ROOT.'/includes/jquery/plugins/jeditable/jquery.jeditable.ui-datepicker.js'.($ext ? '?'.$ext : '').'"></script>'."\n";
		print '<script src="'.DOL_URL_ROOT.'/includes/jquery/plugins/jeditable/jquery.jeditable.ui-autocomplete.js'.($ext ? '?'.$ext : '').'"></script>'."\n";
		print '<script>'."\n";
		print 'var urlSaveInPlace = \''.DOL_URL_ROOT.'/core/ajax/saveinplace.php\';'."\n";
		print 'var urlLoadInPlace = \''.DOL_URL_ROOT.'/core/ajax/loadinplace.php\';'."\n";
		print 'var tooltipInPlace = \''.$langs->transnoentities('ClickToEdit').'\';'."\n"; // Added in title attribute of span
		print 'var placeholderInPlace = \'&nbsp;\';'."\n"; // If we put another string than $langs->trans("ClickToEdit") here, nothing is shown. If we put empty string, there is error, Why ?
		print 'var cancelInPlace = \''.$langs->trans("Cancel").'\';'."\n";
		print 'var submitInPlace = \''.$langs->trans('Ok').'\';'."\n";
		print 'var indicatorInPlace = \'<img src="'.DOL_URL_ROOT."/theme/".$dyap_conf->theme."/img/working.gif".'">\';'."\n";
		print 'var withInPlace = 300;'; // width in pixel for default string edit
		print '</script>'."\n";
		print '<script src="'.DOL_URL_ROOT.'/core/js/editinplace.js'.($ext ? '?'.$ext : '').'"></script>'."\n";
		print '<script src="'.DOL_URL_ROOT.'/includes/jquery/plugins/jeditable/jquery.jeditable.ckeditor.js'.($ext ? '?'.$ext : '').'"></script>'."\n";
		 */
		wp_enqueue_script( 'dyapress-jquery-jeditable', DOL_URL_ROOT.'/includes/jquery/plugins/jeditable/jquery.jeditable.min.js'.$ext, array( 'jquery-ui-widget' ), null );
		wp_enqueue_script( 'dyapress-jquery-jeditable-ui-datepicker', DOL_URL_ROOT.'/includes/jquery/plugins/jeditable/jquery.jeditable.ui-datepicker.js'.$ext, array( 'dyapress-jquery-jeditable' ), null );
		wp_enqueue_script( 'dyapress-jquery-jeditable-ui-autocomplete', DOL_URL_ROOT.'/includes/jquery/plugins/jeditable/jquery.jeditable.ui-autocomplete.js'.$ext, array( 'dyapress-jquery-jeditable' ), null );
		wp_enqueue_script( 'dyapress-editinplace', DOL_URL_ROOT.'/core/js/editinplace.js'.$ext, array( 'dyapress-jquery-jeditable-ui-datepicker', 'dyapress-jquery-jeditable-ui-autocomplete' ), null );
		wp_add_inline_script( 'dyapress-editinplace', '
		    var urlSaveInPlace = \''.DOL_URL_ROOT.'/core/ajax/saveinplace.php\';
		    var urlLoadInPlace = \''.DOL_URL_ROOT.'/core/ajax/loadinplace.php\';
		    var tooltipInPlace = \''.$dyap_langs->transnoentities('ClickToEdit').'\';
		    var placeholderInPlace = \'&nbsp;\';
		    var cancelInPlace = \''.$dyap_langs->trans('Cancel').'\';
		    var submitInPlace = \''.$dyap_langs->trans('Ok').'\';
		    var indicatorInPlace = \'<img src="'.DOL_URL_ROOT."/theme/".$dyap_conf->theme."/img/working.gif".'">\';
		    var withInPlace = 300;' );
		wp_enqueue_script( 'dyapress-jquery-jeditable-ckeditor', DOL_URL_ROOT.'/includes/jquery/plugins/jeditable/jquery.jeditable.ckeditor.js'.$ext, array( 'dyapress-jquery-jeditable' ), null );
	    }
	    // jQuery Timepicker
	    if (!empty($dyap_conf->global->MAIN_USE_JQUERY_TIMEPICKER) || defined('REQUIRE_JQUERY_TIMEPICKER')) {
		/* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
		print '<script src="'.DOL_URL_ROOT.'/includes/jquery/plugins/timepicker/jquery-ui-timepicker-addon.js'.($ext ? '?'.$ext : '').'"></script>'."\n";
		print '<script src="'.DOL_URL_ROOT.'/core/js/timepicker.js.php?lang='.$langs->defaultlang.($ext ? '&amp;'.$ext : '').'"></script>'."\n";
		 */
		wp_enqueue_script( 'dyapress-jquery-timepicker', DOL_URL_ROOT.'/includes/jquery/plugins/timepicker/jquery-ui-timepicker-addon.js'.$ext, array( 'jquery-ui-widget' ), null );
		wp_enqueue_script( 'dyapress-timepicker', DOL_URL_ROOT.'/core/js/timepicker.js'.$ext.'&lang='.$dyap_langs->defaultlang, array( 'dyapress-jquery-timepicker' ), null );
	    }
	    if (!defined('DISABLE_SELECT2') && (!empty($dyap_conf->global->MAIN_USE_JQUERY_MULTISELECT) || defined('REQUIRE_JQUERY_MULTISELECT'))) {
		// jQuery plugin "mutiselect", "multiple-select", "select2", ...
		$tmpplugin = empty($dyap_conf->global->MAIN_USE_JQUERY_MULTISELECT) ?constant('REQUIRE_JQUERY_MULTISELECT') : $dyap_conf->global->MAIN_USE_JQUERY_MULTISELECT;
		/* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
		print '<script src="'.DOL_URL_ROOT.'/includes/jquery/plugins/'.$tmpplugin.'/dist/js/'.$tmpplugin.'.full.min.js'.($ext ? '?'.$ext : '').'"></script>'."\n"; // We include full because we need the support of containerCssClass
		 */
		wp_enqueue_script( 'dyapress-jquery-select2', DOL_URL_ROOT.'/includes/jquery/plugins/'.$tmpplugin.'/dist/js/'.$tmpplugin.'.full.min.js'.$ext, array( 'jquery-ui-widget' ), null );
	    }
	    if (!defined('DISABLE_MULTISELECT')) {     // jQuery plugin "mutiselect" to select with checkboxes. Can be removed once we have an enhanced search tool
		/* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
		print '<script src="'.DOL_URL_ROOT.'/includes/jquery/plugins/multiselect/jquery.multi-select.js'.($ext ? '?'.$ext : '').'"></script>'."\n";
		 */
		wp_enqueue_script( 'dyapress-jquery-multiselect', DOL_URL_ROOT.'/includes/jquery/plugins/multiselect/jquery.multi-select.js'.$ext, array( 'jquery-ui-widget' ), null );
	    }
	}

	if (!$disablejs && !empty($dyap_conf->use_javascript_ajax)) {
	    // CKEditor
	    if ((!empty($dyap_conf->fckeditor->enabled) && (empty($dyap_conf->global->FCKEDITOR_EDITORNAME) || $dyap_conf->global->FCKEDITOR_EDITORNAME == 'ckeditor') && !defined('DISABLE_CKEDITOR')) || defined('FORCE_CKEDITOR')) {
		/* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
		print '<!-- Includes JS for CKEditor -->'."\n";
		$pathckeditor = DOL_URL_ROOT.'/includes/ckeditor/ckeditor/';
		$jsckeditor = 'ckeditor.js';
		if (constant('JS_CKEDITOR')) {
		    // To use external ckeditor 4 js lib
		    $pathckeditor = constant('JS_CKEDITOR');
		}
		print '<script>';
		print 'var CKEDITOR_BASEPATH = \''.dol_escape_js($pathckeditor).'\';'."\n";
		print 'var ckeditorConfig = \''.dol_escape_js(dol_buildpath($themesubdir.'/theme/'.$dyap_conf->theme.'/ckeditor/config.js'.($ext ? '?'.$ext : ''), 1)).'\';'."\n"; // $themesubdir='' in standard usage
		print 'var ckeditorFilebrowserBrowseUrl = \''.DOL_URL_ROOT.'/core/filemanagerdol/browser/default/browser.php?Connector='.DOL_URL_ROOT.'/core/filemanagerdol/connectors/php/connector.php\';'."\n";
		print 'var ckeditorFilebrowserImageBrowseUrl = \''.DOL_URL_ROOT.'/core/filemanagerdol/browser/default/browser.php?Type=Image&Connector='.DOL_URL_ROOT.'/core/filemanagerdol/connectors/php/connector.php\';'."\n";
		print '</script>'."\n";
		print '<script src="'.$pathckeditor.$jsckeditor.($ext ? '?'.$ext : '').'"></script>'."\n";
		print '<script>';
		if (GETPOST('mode', 'aZ09') == 'Full_inline') {
		    print 'CKEDITOR.disableAutoInline = false;'."\n";
		} else {
		    print 'CKEDITOR.disableAutoInline = true;'."\n";
		}
		print '</script>'."\n";
		 */
		$pathckeditor = constant('JS_CKEDITOR') ? constant('JS_CKEDITOR') : DOL_URL_ROOT . '/includes/ckeditor/ckeditor/';
		$jsckeditor='ckeditor.js';
		wp_add_inline_script( 'jquery-ui-widget', '
		    var CKEDITOR_BASEPATH = \''.\DyaPress\dol_escape_js($pathckeditor).'\';
		    var ckeditorConfig = \''.\DyaPress\dol_escape_js(dyap_url($themesubdir.'/theme/'.$dyap_conf->theme.'/ckeditor/config.js'.$ext)).'\';
		    var ckeditorFilebrowserBrowseUrl = \''.DOL_URL_ROOT.'/core/filemanagerdol/browser/default/browser.php?Connector='.DOL_URL_ROOT.'/core/filemanagerdol/connectors/php/connector.php\';
		    var ckeditorFilebrowserImageBrowseUrl = \''.DOL_URL_ROOT.'/core/filemanagerdol/browser/default/browser.php?Type=Image&Connector='.DOL_URL_ROOT.'/core/filemanagerdol/connectors/php/connector.php\';
		    CKEDITOR.disableAutoInline = '.(\DyaPress\GETPOST('mode', 'aZ09') == 'Full_inline' ? 'false' : 'true').';' );
		wp_enqueue_script( 'dyapress-ckeditor', $pathckeditor.$jsckeditor.$ext, array( 'jquery-ui-widget' ), null );
	    }

	    // Browser notifications (if NOREQUIREMENU is on, it is mostly a page for popup, so we do not enable notif too. We hide also for public pages).
	    if (!defined('NOBROWSERNOTIF') && !defined('NOREQUIREMENU') && !defined('NOLOGIN')) {
		$enablebrowsernotif = false;
		if (!empty($dyap_conf->agenda->enabled) && !empty($dyap_conf->global->AGENDA_REMINDER_BROWSER)) {
		    $enablebrowsernotif = true;
		}
		if ($dyap_conf->browser->layout == 'phone') {
		    $enablebrowsernotif = false;
		}
		if ($enablebrowsernotif) {
		    /* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
		    print '<!-- Includes JS of Dolibarr (browser layout = '.$dyap_conf->browser->layout.')-->'."\n";
		    print '<script src="'.DOL_URL_ROOT.'/core/js/lib_notification.js.php'.($ext ? '?'.$ext : '').'"></script>'."\n";
		     */
		    wp_enqueue_script( 'dyapress-lib_notification', DOL_URL_ROOT.'/core/js/lib_notification.js.php'.$ext, array( 'jquery-ui-widget' ), null );
		}
	    }

	    // Global js function
	    /* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
	    print '<!-- Includes JS of Dolibarr -->'."\n";
	    print '<script src="'.DOL_URL_ROOT.'/core/js/lib_head.js.php?lang='.$langs->defaultlang.($ext ? '&amp;'.$ext : '').'"></script>'."\n";
	     */
	    wp_enqueue_script( 'dyapress', dyap_url('/core/js/lib_head.js.php'.$ext.'&lang='.$dyap_langs->defaultlang), array( 'jquery-ui-widget', 'jquery-ui-dialog' ), null );

	    // JS forced by modules (relative url starting with /)
	    if (!empty($dyap_conf->modules_parts['js'])) {		// $dyap_conf->modules_parts['js'] is array('module'=>array('file1','file2'))
		$arrayjs = (array) $dyap_conf->modules_parts['js'];
		foreach ($arrayjs as $modjs => $filesjs) {
		    $filesjs = (array) $filesjs; // To be sure filejs is an array
		    foreach ($filesjs as $jsfile) {
			// jsfile is a relative path
			$urlforjs = dol_buildpath($jsfile, 1);
			if ($urlforjs && $urlforjs != '/') {
			    /* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
			    print '<!-- Include JS added by module '.$modjs.'-->'."\n".'<script src="'.$urlforjs.((strpos($jsfile, '?') === false) ? '?' : '&amp;').'lang='.$langs->defaultlang.'"></script>'."\n";
			     */
			    wp_enqueue_script( 'dyapress-module-'.$modjs,$urlforjs.((strpos($jsfile, '?') === false) ? '?' : '&amp;').'lang='.$langs->defaultlang, array(), null );
			} else {
			    dol_syslog("Warning: module ".$modjs." declared a js path file for a file we can't find.", LOG_WARNING);
			}
		    }
		}
	    }
	    // JS forced by page in top_htmlhead (relative url starting with /)
	    if (is_array($arrayofjs)) {
		// DyaPress code removed: print '<!-- Includes JS added by page -->'."\n";
		$i = 1;
		foreach ($arrayofjs as $jsfile) {
		    if (preg_match('/^(http|\/\/)/i', $jsfile)) {
			/* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
			print '<script src="'.$jsfile.((strpos($jsfile, '?') === false) ? '?' : '&amp;').'lang='.$langs->defaultlang.'"></script>'."\n";
			 */
			wp_enqueue_script( 'dyapress-arrayofjs-'.$i++, $jsfile.((strpos($jsfile, '?') === false) ? '?' : '&amp;').'lang='.$langs->defaultlang, array( 'dyapress' ), DYAPRESS_VERSION );
		    } else {
			/* DyaPress: code migrated to WordPress (take care $ext has already been prefixed with ? furthermore) :
			print '<script src="'.dol_buildpath($jsfile, 1).((strpos($jsfile, '?') === false) ? '?' : '&amp;').'lang='.$langs->defaultlang.'"></script>'."\n";
			 */
			wp_enqueue_script( 'dyapress-arrayofjs-'.$i++, \dyap_url($jsfile).((strpos($jsfile, '?') === false) ? '?' : '&amp;').'lang='.$langs->defaultlang, array( 'dyapress' ), DYAPRESS_VERSION );
		    }
		}
	    }
	}

	/* DyaPress code removed:
	if (!empty($dyap_conf->global->MAIN_HTML_HEADER)) {
	    print $dyap_conf->global->MAIN_HTML_HEADER."\n";
	}

	$parameters = array();
	$result = $dyap_hookmanager->executeHooks('addHtmlHeader', $parameters); // Note that $action and $object may have been modified by some hooks
	print $dyap_hookmanager->resPrint; // Replace Title to show
	 */
    }
}

add_action( 'plugins_loaded', array( 'DyaPress', 'get_instance' ) );
